@@ -2,7 +2,7 @@
  * nav.c: wrappers to libdvdread read functions.
  *****************************************************************************
  * Copyright (C) 2002 VideoLAN
- * $Id: nav.c,v 1.10 2003/01/30 09:58:05 sam Exp $
+ * $Id: nav.c,v 1.13 2003/03/09 16:13:13 gbazin Exp $
  *
  * Authors: Stphane Borel <stef@via.ecp.fr>
  *
@@ -218,6 +218,20 @@ int dvdplay_seek( dvdplay_ptr dvdplay, int i_off )
 
     p_pgc = dvdplay->state.p_pgc;
 
+    if( dvdplay->state.domain == FP_DOMAIN )
+    {
+        return -1;
+    }
+
+    if( dvdplay->state.domain == FP_DOMAIN )
+      _dvdplay_err( dvdplay,"FP_DOMAIN");
+    if( dvdplay->state.domain == VMGM_DOMAIN )
+      _dvdplay_err( dvdplay,"VMGM_DOMAIN");
+    if( dvdplay->state.domain == VTSM_DOMAIN )
+      _dvdplay_err( dvdplay,"VTSM_DOMAIN");
+    if( dvdplay->state.domain == VTS_DOMAIN )
+      _dvdplay_err( dvdplay,"VTS_DOMAIN");
+
     i_pgc_block = dvdplay_title_first( dvdplay );
     i_block = i_pgc_block + i_off;
 
@@ -228,29 +242,64 @@ int dvdplay_seek( dvdplay_ptr dvdplay, int i_off )
     {
         ++i_cell;
     }
-
     if( i_cell > p_pgc->nr_of_cells )
     {
-        _dvdplay_err( dvdplay, "seeking to block %d failed (nonexistent block)",
-                               i_block );
+        _dvdplay_err( dvdplay,
+                      "seeking to block %d failed (nonexistent block)",
+                      i_block );
         return -1;
     }
+    dvdplay->state.i_cellN  = i_cell;
 
     /* find vobu containing our block */
-    i_vobu = 1;
-    i_admap_entries = ( dvdplay->p_vtsi->vts_vobu_admap->last_byte + 1
-                        - VOBU_ADMAP_SIZE ) / 4;
-    while( i_vobu < i_admap_entries &&
-           dvdplay->p_vtsi->vts_vobu_admap->vobu_start_sectors[i_vobu]
-             <= i_block )
+    if( dvdplay->state.domain == VTS_DOMAIN )
     {
-        ++i_vobu;
-    }
+        i_vobu = 1;
+        i_admap_entries = ( dvdplay->p_vtsi->vts_vobu_admap->last_byte + 1
+                            - VOBU_ADMAP_SIZE ) / 4;
+        while( i_vobu < i_admap_entries &&
+               dvdplay->p_vtsi->vts_vobu_admap->vobu_start_sectors[i_vobu]
+                 <= i_block )
+        {
+            ++i_vobu;
+        }
 
-    dvdplay->state.i_cellN  = i_cell;
-    dvdplay->state.i_blockN =
-        dvdplay->p_vtsi->vts_vobu_admap->vobu_start_sectors[i_vobu-1] -
-        p_pgc->cell_playback[i_cell-1].first_sector;
+        dvdplay->state.i_blockN =
+            dvdplay->p_vtsi->vts_vobu_admap->vobu_start_sectors[i_vobu-1] -
+            p_pgc->cell_playback[i_cell-1].first_sector;
+    }
+    else if( dvdplay->state.domain == VTSM_DOMAIN )
+    {
+        i_vobu = 1;
+        i_admap_entries = ( dvdplay->p_vtsi->menu_vobu_admap->last_byte + 1
+                            - VOBU_ADMAP_SIZE ) / 4;
+        while( i_vobu < i_admap_entries &&
+               dvdplay->p_vtsi->menu_vobu_admap->vobu_start_sectors[i_vobu]
+                 <= i_block )
+        {
+            ++i_vobu;
+        }
+
+        dvdplay->state.i_blockN =
+            dvdplay->p_vtsi->menu_vobu_admap->vobu_start_sectors[i_vobu-1] -
+            p_pgc->cell_playback[i_cell-1].first_sector;
+    }
+    else if( dvdplay->state.domain == VMGM_DOMAIN )
+    {
+        i_vobu = 1;
+        i_admap_entries = ( dvdplay->p_vmgi->menu_vobu_admap->last_byte + 1
+                            - VOBU_ADMAP_SIZE ) / 4;
+        while( i_vobu < i_admap_entries &&
+               dvdplay->p_vmgi->menu_vobu_admap->vobu_start_sectors[i_vobu]
+                 <= i_block )
+        {
+            ++i_vobu;
+        }
+
+        dvdplay->state.i_blockN =
+            dvdplay->p_vmgi->menu_vobu_admap->vobu_start_sectors[i_vobu-1] -
+            p_pgc->cell_playback[i_cell-1].first_sector;
+    }
 
     dvdplay_nav( dvdplay );
 
